//////////////////////////////////////////////////////////////////////////////////////////////
// Copyright 2016 Leszek Koltunski                                                          //
//                                                                                          //
// This file is part of Distorted.                                                          //
//                                                                                          //
// Distorted is free software: you can redistribute it and/or modify                        //
// it under the terms of the GNU General Public License as published by                     //
// the Free Software Foundation, either version 2 of the License, or                        //
// (at your option) any later version.                                                      //
//                                                                                          //
// Distorted is distributed in the hope that it will be useful,                             //
// but WITHOUT ANY WARRANTY; without even the implied warranty of                           //
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the                            //
// GNU General Public License for more details.                                             //
//                                                                                          //
// You should have received a copy of the GNU General Public License                        //
// along with Distorted.  If not, see <http://www.gnu.org/licenses/>.                       //
//////////////////////////////////////////////////////////////////////////////////////////////

precision lowp float;

varying vec2 v_TexCoordinate;
uniform sampler2D u_Texture;
uniform vec2 u_objD;
uniform int pNumEffects;                 // total number of postprocessing effects

#if NUM_POSTPROCESS>0
uniform int pType[NUM_POSTPROCESS];      // their types.
uniform vec4 pUniforms[NUM_POSTPROCESS]; // i-th effect is 1 vec4: [i].

//////////////////////////////////////////////////////////////////////////////////////////////
// BLUR EFFECT

void blur(out vec4 pixel,float radius)
  {
  pixel = vec4(0.0);

  float blurSizeH = 1.0 / u_objD.x;
  float blurSizeV = 1.0 / u_objD.y;
  float denom     = 1.0 / ((2.0*radius+1.0)*(2.0*radius+1.0));

  for (float x = -radius; x <= radius; x+=1.0)
    for (float y = -radius; y <= radius; y+=1.0)
      {
      pixel += texture2D( u_Texture, vec2(v_TexCoordinate.x + x*blurSizeH, v_TexCoordinate.y + y*blurSizeV) ) *denom;
      }
  }

#endif

//////////////////////////////////////////////////////////////////////////////////////////////

void main()
  {
  vec4 pixel = texture2D(u_Texture,v_TexCoordinate);

#if NUM_POSTPROCESS>0
  for(int i=0; i<pNumEffects; i++)
    {
    if( pType[i]==BLUR ) blur(pixel,pUniforms[i].x);
    }
#endif

  gl_FragColor = pixel;
  }